==> myriad-laravel-validators-3.3.1-a65a23.tar: README.md <==
# Laravel Validators

## Install

### Add Myriad Repository

The client is distributed internally with Satis. First add the repository to `composer.json`:

```json
  "repositories": [
    {
      "type": "composer",
      "url": "https://satis.myriadmobile.com"
    }
  ]
```

### Require the Dependency

Require this package with composer using the following command:

```bash
composer require myriad/laravel-validators
```

### Install Service Provider

After updating composer, add the service provider to the `providers` array in `config/app.php`:

```php
Myriad\Validators\ValidatorServiceProvider::class,
```

## Validators

__csv:*rules*__

The field under validation must be a valid csv according to `str_getcsv`.
Most strings will pass as a single value csv such as `blah` is technically valid.
The real power comes from being able to assign rules to each value.

Rules are formatted in the normal Laravel syntax replacing `|` with `\`.
Any rules known the the validator should work.

Examples:
`csv:required`
Ensure that all values are non-empty. ex. `1,2,,3` will fail.

`csv:min:2\in:aa,bb,cc`
Ensure that all values are at minimum 2 characters and one of `aa`, `bb`, or `cc`.


__locale:*format*__
TODO

__uuid:*version*__

The field under validation must be a valid uuid according to `\Ramsey\Uuid\Uuid::fromString`.
Optionally the uuid may be restricted to a certain version.

Examples:
`uuid:1`
The field under validation must be a time-based (v1) uuid.
`uuid:3,5`
The field under validation must be either a name-based md5 (v3) or name-based sha1 (v5) uuid.
`uuid:4`
The field under validation must be a random (v4) uuid.

==> myriad-laravel-validators-3.5.1-58411a.tar: README.md <==
# Laravel Validators

## Install

### Add Myriad Repository

The client is distributed internally with Satis. First add the repository to `composer.json`:

```json
  "repositories": [
    {
      "type": "composer",
      "url": "https://satis.bushelops.com"
    }
  ]
```

### Require the Dependency

Require this package with composer using the following command:

```bash
composer require myriad/laravel-validators
```

### Install Service Provider

After updating composer, add the service provider to the `providers` array in `config/app.php`:

```php
Myriad\Validators\ValidatorServiceProvider::class,
```

## Validators

__csv:*rules*__

The field under validation must be a valid csv according to `str_getcsv`.
Most strings will pass as a single value csv such as `blah` is technically valid.
The real power comes from being able to assign rules to each value.

Rules are formatted in the normal Laravel syntax replacing `|` with `\`.
Any rules known the the validator should work.

Examples:
`csv:required`
Ensure that all values are non-empty. ex. `1,2,,3` will fail.

`csv:min:2\in:aa,bb,cc`
Ensure that all values are at minimum 2 characters and one of `aa`, `bb`, or `cc`.


__locale:*format*__
TODO

__uuid:*version*__

The field under validation must be a valid uuid according to `\Ramsey\Uuid\Uuid::fromString`.
Optionally the uuid may be restricted to a certain version.

Examples:
`uuid:1`
The field under validation must be a time-based (v1) uuid.
`uuid:3,5`
The field under validation must be either a name-based md5 (v3) or name-based sha1 (v5) uuid.
`uuid:4`
The field under validation must be a random (v4) uuid.
